@@ -39,7 +39,7 @@ class AbstractDeleteTime(AbstractCreateUpdateTime):
         elif not self.is_deleted and self.deleted_time:
             self.deleted_time = None
 
-        super().save(self, *args, **kwargs)
+        super().save(*args, **kwargs)
 
     class Meta:
         abstract = True
